@@ -1,22 +1,21 @@
-"""
-Copyright 2015 Rackspace
-
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-   http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-"""
+# Copyright 2015 Rackspace
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 import syntribos.extensions.identity.models.base
 
 
 class Auth(syntribos.extensions.identity.models.base.BaseIdentityModel):
+
     def __init__(
             self, identity=None, scope=None):
         super(Auth, self).__init__(locals())
@@ -28,6 +27,7 @@ class Auth(syntribos.extensions.identity.models.base.BaseIdentityModel):
 
 
 class Identity(syntribos.extensions.identity.models.base.BaseIdentityModel):
+
     def __init__(self, token=None, password=None, methods=None):
         super(Identity, self).__init__(locals())
 
@@ -39,6 +39,7 @@ class Identity(syntribos.extensions.identity.models.base.BaseIdentityModel):
 
 
 class Password(syntribos.extensions.identity.models.base.BaseIdentityModel):
+
     def __init__(self, user=None):
         super(Password, self).__init__(locals())
 
@@ -48,6 +49,7 @@ class Password(syntribos.extensions.identity.models.base.BaseIdentityModel):
 
 
 class User(syntribos.extensions.identity.models.base.BaseIdentityModel):
+
     def __init__(self, id_=None, password=None, name=None, domain=None):
         super(User, self).__init__(locals())
 
@@ -60,6 +62,7 @@ class User(syntribos.extensions.identity.models.base.BaseIdentityModel):
 
 
 class Token(syntribos.extensions.identity.models.base.BaseIdentityModel):
+
     def __init__(self, id_=None):
         super(Token, self).__init__(locals())
 
@@ -68,16 +71,17 @@ class Token(syntribos.extensions.identity.models.base.BaseIdentityModel):
 
 
 class Scope(syntribos.extensions.identity.models.base.BaseIdentityModel):
+
     def __init__(self, project=None, domain=None):
         super(Scope, self).__init__(locals())
 
     def _obj_to_dict(self):
         return self._remove_empty_values({
-            "project": self._get_sub_model(self.project),
-            "domain": self._get_sub_model(self.domain)})
+            "project": self._get_sub_model(self.project)})
 
 
 class Domain(syntribos.extensions.identity.models.base.BaseIdentityModel):
+
     def __init__(self, name=None, id_=None):
         super(Domain, self).__init__(locals())
 
@@ -87,7 +91,8 @@ class Domain(syntribos.extensions.identity.models.base.BaseIdentityModel):
             "id": self.id_})
 
 
-class Project(Domain):
+class Project(syntribos.extensions.identity.models.base.BaseIdentityModel):
+
     def __init__(self, name=None, id_=None, domain=None):
         super(Project, self).__init__(locals())
 
