@@ -11,21 +11,23 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import threading
 import time
 import unittest
 
 from oslo_config import cfg
 
 import syntribos
+from syntribos._i18n import _
 from syntribos.formatters.json_formatter import JSONFormatter
 from syntribos.runner import Runner
 import syntribos.utils.remotes
 
 CONF = cfg.CONF
+lock = threading.Lock()
 
 
 class IssueTestResult(unittest.TextTestResult):
-
     """Custom unnittest results holder class
 
     This class aggregates :class:`syntribos.issue.Issue` objects from all the
@@ -33,9 +35,12 @@ class IssueTestResult(unittest.TextTestResult):
     """
     output = {"failures": {}, "errors": [], "stats": {}}
     output["stats"]["severity"] = {
-        "UNDEFINED": 0, "LOW": 0, "MEDIUM": 0, "HIGH": 0
+        "UNDEFINED": 0,
+        "LOW": 0,
+        "MEDIUM": 0,
+        "HIGH": 0
     }
-    stats = {"errors": 0, "failures": 0, "successes": 0}
+    stats = {"errors": 0, "unique_failures": 0, "successes": 0}
     severity_counter_dict = {}
     testsRunSinceLastPrint = 0
     failure_id = 0
@@ -81,10 +86,13 @@ class IssueTestResult(unittest.TextTestResult):
         :type test: :class:`syntribos.tests.base.BaseTestCase`
         :param tuple err: Tuple of format ``(type, value, traceback)``
         """
+        lock.acquire()
         for issue in test.failures:
             defect_type = issue.defect_type
-            if any([True for x in CONF.syntribos.exclude_results
-                    if x and x in defect_type]):
+            if any([
+                    True for x in CONF.syntribos.exclude_results
+                    if x and x in defect_type
+            ]):
                 continue
 
             min_sev = syntribos.RANKING_VALUES[CONF.min_severity]
@@ -143,7 +151,7 @@ class IssueTestResult(unittest.TextTestResult):
 
                 instance_obj = None
                 for i in failure_obj["instances"]:
-                    if(i["confidence"] == conf_rating and
+                    if (i["confidence"] == conf_rating and
                             i["severity"] == sev_rating and
                             i["param"]["method"] == method and
                             i["param"]["location"] == loc):
@@ -151,8 +159,8 @@ class IssueTestResult(unittest.TextTestResult):
                         i["param"]["variables"].add(name)
                         for sig_type in signals:
                             if sig_type in i["signals"]:
-                                i["signals"][sig_type].update(
-                                    signals[sig_type])
+                                i["signals"][sig_type].update(signals[
+                                    sig_type])
                             else:
                                 i["signals"][sig_type] = signals[sig_type]
                         i["strings"].add(payload_string)
@@ -169,17 +177,17 @@ class IssueTestResult(unittest.TextTestResult):
                         "signals": signals
                     }
                     failure_obj["instances"].append(instance_obj)
-                    self.stats["failures"] += 1
+                    self.stats["unique_failures"] += 1
                     self.output["stats"]["severity"][sev_rating] += 1
             else:
                 instance_obj = None
                 for i in failure_obj["instances"]:
-                    if(i["confidence"] == conf_rating and
+                    if (i["confidence"] == conf_rating and
                             i["severity"] == sev_rating):
                         for sig_type in signals:
                             if sig_type in i["signals"]:
-                                i["signals"][sig_type].update(
-                                    signals[sig_type])
+                                i["signals"][sig_type].update(signals[
+                                    sig_type])
                             else:
                                 i["signals"][sig_type] = signals[sig_type]
                         instance_obj = i
@@ -191,8 +199,9 @@ class IssueTestResult(unittest.TextTestResult):
                         "signals": signals
                     }
                     failure_obj["instances"].append(instance_obj)
-                    self.stats["failures"] += 1
+                    self.stats["unique_failures"] += 1
                     self.output["stats"]["severity"][sev_rating] += 1
+        lock.release()
 
     def addError(self, test, err):
         """Duplicates parent class addError functionality.
@@ -202,12 +211,19 @@ class IssueTestResult(unittest.TextTestResult):
         :param err:
         :type tuple: Tuple of format ``(type, value, traceback)``
         """
-        self.errors.append(
-            {
-                "test": self.getDescription(test),
+        with lock:
+            for e in self.errors:
+                if e['error'] == self._exc_info_to_string(err, test):
+                    if self.getDescription(test) in e['test']:
+                        return
+                    e['test'].append(self.getDescription(test))
+                    self.stats["errors"] += 1
+                    return
+            self.errors.append({
+                "test": [self.getDescription(test)],
                 "error": self._exc_info_to_string(err, test)
             })
-        self.stats["errors"] += 1
+            self.stats["errors"] += 1
 
     def addSuccess(self, test):
         """Duplicates parent class addSuccess functionality.
@@ -215,7 +231,8 @@ class IssueTestResult(unittest.TextTestResult):
         :param test: The test that was run
         :type test: :class:`syntribos.tests.base.BaseTestCase`
         """
-        self.stats["successes"] += 1
+        with lock:
+            self.stats["successes"] += 1
 
     def printErrors(self, output_format):
         """Print out each :class:`syntribos.issue.Issue` that was encountered
@@ -224,9 +241,7 @@ class IssueTestResult(unittest.TextTestResult):
         """
         self.output["errors"] = self.errors
         self.output["failures"] = self.failures
-        formatter_types = {
-            "json": JSONFormatter(self)
-        }
+        formatter_types = {"json": JSONFormatter(self)}
         formatter = formatter_types[output_format]
         formatter.report(self.output)
 
@@ -239,16 +254,20 @@ class IssueTestResult(unittest.TextTestResult):
         """Print the path to the log folder for this run."""
         test_log = Runner.log_path
         run_time = time.time() - start_time
-        num_fail = self.stats["failures"]
+        num_fail = self.stats["unique_failures"]
         num_err = self.stats["errors"]
         print("\n{sep}\nTotal: Ran {num} test{suff} in {time:.3f}s".format(
-            sep=syntribos.SEP, num=self.testsRun,
-            suff="s" * bool(self.testsRun - 1), time=run_time))
-        print("Total: {f} failure{fsuff} and {e} error{esuff}".format(
-            f=num_fail, e=num_err,
-            fsuff="s" * bool(num_fail - 1),
-            esuff="s" * bool(num_err - 1)))
+            sep=syntribos.SEP,
+            num=self.testsRun,
+            suff="s" * bool(self.testsRun - 1),
+            time=run_time))
+        print("Total: {f} unique failure{fsuff} "
+              "and {e} unique error{esuff}".format(
+                  f=num_fail,
+                  e=num_err,
+                  fsuff="s" * bool(num_fail - 1),
+                  esuff="s" * bool(num_err - 1)))
         if test_log:
             print(syntribos.SEP)
-            print("LOG PATH...: {path}".format(path=test_log))
+            print(_("LOG PATH...: %s") % test_log)
             print(syntribos.SEP)
